@@ -40,7 +40,8 @@ CV<-sqrt(MSerror)*100/Mean
 means <- tapply.stat(junto[,1],junto[,2],stat="mean") # change
 sds <-   tapply.stat(junto[,1],junto[,2],stat="sd") #change
 nn <-   tapply.stat(junto[,1],junto[,2],stat="length") # change
-means<-data.frame(means,std=sds[,2],r=nn[,2],medians)
+std.err <- sqrt(MSerror)/sqrt(nn[, 2]) # change sds[,2]
+means<-data.frame(means,std=sds[,2],r=nn[,2],se=std.err,medians)
 names(means)[1:2]<-c(name.t,name.y)
 
 #   row.names(means)<-means[,1]
@@ -60,7 +61,7 @@ cat("\nStudy:", main)
 cat("\n\nRyan, Einot and Gabriel and Welsch multiple range test\nfor",name.y,"\n")
 cat("\nMean Square Error: ",MSerror,"\n\n")
 cat(paste(name.t,",",sep="")," means\n\n")
-print(data.frame(row.names = means[,1], means[,2:6]))
+print(data.frame(row.names = means[,1], means[,-1]))
 }
 if(length(nr) == 1 ) sdtdif <- sqrt(MSerror/nr)
 else {
