@@ -40,7 +40,8 @@ CV<-sqrt(MSerror)*100/Mean
 means <- tapply.stat(junto[,1],junto[,2],stat="mean") # change
 sds <-   tapply.stat(junto[,1],junto[,2],stat="sd") #change
 nn <-   tapply.stat(junto[,1],junto[,2],stat="length") # change
-means<-data.frame(means,std=sds[,2],r=nn[,2],medians)
+std.err <- sqrt(MSerror)/sqrt(nn[, 2]) # change sds[,2]
+means<-data.frame(means,std=sds[,2],r=nn[,2],se=std.err,medians)
 names(means)[1:2]<-c(name.t,name.y)
 ntr<-nrow(means)
 Tprob <- qtukey(1-alpha,2:ntr, DFerror)
@@ -51,7 +52,7 @@ cat("\nStudy:", main)
 cat("\n\nStudent Newman Keuls Test\nfor",name.y,"\n")
 cat("\nMean Square Error: ",MSerror,"\n\n")
 cat(paste(name.t,",",sep="")," means\n\n")
-print(data.frame(row.names = means[,1], means[,2:6]))
+print(data.frame(row.names = means[,1], means[,-1]))
 }
 if(length(nr) == 1 ) sdtdif <- sqrt(MSerror/nr)
 else {
