@@ -41,7 +41,8 @@ function (y, trt, DFerror, MSerror, Fc, alpha=0.05, group=TRUE,main = NULL,conso
 	means <- tapply.stat(junto[,1],junto[,2],stat="mean") # change
 	sds <-   tapply.stat(junto[,1],junto[,2],stat="sd") #change
 	nn <-   tapply.stat(junto[,1],junto[,2],stat="length") # change
-	means<-data.frame(means,std=sds[,2],r=nn[,2],medians)
+	std.err <- sqrt(MSerror)/sqrt(nn[, 2]) # change sds[,2]
+	means<-data.frame(means,std=sds[,2],r=nn[,2],se=std.err,medians)
 	names(means)[1:2]<-c(name.t,name.y)
 #   row.names(means)<-means[,1]
 	ntr<-nrow(means)
@@ -53,7 +54,7 @@ function (y, trt, DFerror, MSerror, Fc, alpha=0.05, group=TRUE,main = NULL,conso
 	cat("\n\nScheffe Test for",name.y,"\n")
 	cat("\nMean Square Error  :",MSerror,"\n\n")
 	cat(paste(name.t,",",sep="")," means\n\n")
-	print(data.frame(row.names = means[,1], means[,2:6]))
+	print(data.frame(row.names = means[,1], means[,-1]))
 	cat("\nAlpha:",alpha,"; DF Error:",DFerror,"\n")
 	cat("Critical Value of F:", Fprob,"\n")
 	}
