@@ -31,13 +31,16 @@ W[6,j]<-B[6,j]+B[11,j]
 W[11,j]<-B[8,j]+B[12,j]+B[13,j]+B[15,j]
 }
 W[,3]<-W[,2]/W[,1]
+W[1,4]<-W[1,3]/W[11,3]
 W[2,4]<-W[2,3]/W[3,3]
 W[4:5,4]<-W[4:5,3]/W[6,3]
 W[7:10,4]<-W[7:10,3]/W[11,3]
 # Pvalue
+W[1,5]<-1-pf(W[1,4],W[1,1],W[11,1])
 W[2,5]<-1-pf(W[2,4],W[2,1],W[3,1])
 W[4:5,5]<-1-pf(W[4:5,4],W[4:5,1],W[6,1])
 W[7:10,5]<-1-pf(W[7:10,4],W[7:10,1],W[11,1])
+W[c(3,6,11),4:5]<-NA
 #W[,5]<-round(W[,5],4)
 N<-NULL
 N[1]<- name.r
